/*
 * This file is a part of KleanSweep.
 *
 * Copyright (C) 2005 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * KleanSweep is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#ifndef __SWEEPWIZARD_H
#define __SWEEPWIZARD_H

#include <kwizard.h>
#include "sweepscanner.h"
#include "filelistview.h"

class QCheckBox;
class QLineEdit;
class QPushButton;
class QBoxLayout;
class QPixmap;
class KURLRequester;
class KTabWidget;
class SweepFileInfo;
class LogWidget;
class SummaryLabel;

class SweeperWizard: public KWizard
{
        Q_OBJECT
        
        protected:
                QWidget *resultspage;
		QWidget *welcomepage;
		QWidget *archivepage;
		QWidget *startpage;
		QWidget *removepage;
		KTabWidget *resultstabs;
                SweepScanner *scanner;
                FileListView *views[12];
		FileListView *remview;
		FileListView *lastview;
		LogWidget *logwidget;
		QCheckBox *cb_scan[12];
		QCheckBox *cb_writable;
		QCheckBox *cb_createarch;
		KURLRequester *url_startpath;
		QPixmap *kleansweep_bar1;
		QPushButton *b_selectall;
		QPushButton *b_clearall;
		QPushButton *b_stop;
		SummaryLabel *summary;

		int numchoosen;
		struct ScanOpts
		{
			SweepScanner::FileType ftype;
			QString optname;
			int columns;
			QString info;
		};
		static ScanOpts scanopts[];
		static int DefaultColumns;
		static int ColumnsWithTarget;
                
        protected slots:
                void addFileEntry(SweepScanner::FileType t, SweepFileInfo *f);
                void addFileEntry(SweepScanner::FileType t, SweepFileInfo *f, SweepFileInfo *parent);
		void scannerFinished(bool status);
		void scanCategoryToggled(bool f);
		void openDirectory(const QString &path);
		void selectAllClicked();
		void clearAllClicked();
		void stopClicked();
                
        protected:
                void setupWelcomePage();
                void setupStartPage();
                void setupResultsPage();
		void setupArchivePage();
		void setupRemovePage();
		void addLeftSidePic(QWidget *page, QBoxLayout *parent);

        public:
                SweeperWizard(QWidget *parent);
                ~SweeperWizard();
                virtual void showPage(QWidget *w);
};

#endif
